@@ -20,8 +20,10 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/types"
+	utilclock "k8s.io/apimachinery/pkg/util/clock"
 	"k8s.io/client-go/informers"
 	k8sfake "k8s.io/client-go/kubernetes/fake"
+	"k8s.io/client-go/rest"
 	"k8s.io/client-go/tools/cache"
 	"k8s.io/client-go/util/workqueue"
 	apiregistrationfake "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset/fake"
@@ -32,12 +34,14 @@ import (
 	olmerrors "github.com/operator-framework/operator-lifecycle-manager/pkg/controller/errors"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/registry/grpc"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/registry/reconciler"
+	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/registry/resolver"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/fakes"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/lib/clientfake"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/lib/operatorclient"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/lib/operatorlister"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/lib/ownerutil"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/lib/queueinformer"
+	"github.com/operator-framework/operator-lifecycle-manager/pkg/lib/scoped"
 )
 
 type mockTransitioner struct {
@@ -57,6 +61,8 @@ func (m *mockTransitioner) ExecutePlan(plan *v1alpha1.InstallPlan) error {
 func TestTransitionInstallPlan(t *testing.T) {
 	errMsg := "transition test error"
 	err := errors.New(errMsg)
+	clockFake := utilclock.NewFakeClock(time.Date(2018, time.January, 26, 20, 40, 0, 0, time.UTC))
+	now := metav1.NewTime(clockFake.Now())
 
 	installed := &v1alpha1.InstallPlanCondition{
 		Type:   v1alpha1.InstallPlanInstalled,
@@ -102,7 +108,7 @@ func TestTransitionInstallPlan(t *testing.T) {
 		transitioner := &mockTransitioner{tt.transError}
 
 		// Attempt to transition phases.
-		out, _ := transitionInstallPlanState(logrus.New(), transitioner, *plan)
+		out, _ := transitionInstallPlanState(logrus.New(), transitioner, *plan, now)
 
 		// Assert that the final phase is as expected.
 		require.Equal(t, tt.expected, out.Status.Phase)
@@ -120,6 +126,214 @@ func TestTransitionInstallPlan(t *testing.T) {
 	}
 }
 
+func TestEnsureCRDVersions(t *testing.T) {
+	mainCRDPlural := "ins-main-abcde"
+
+	currentVersions := []v1beta1.CustomResourceDefinitionVersion{
+		{
+			Name:    "v1alpha1",
+			Served:  true,
+			Storage: true,
+		},
+	}
+
+	addedVersions := []v1beta1.CustomResourceDefinitionVersion{
+		{
+			Name:    "v1alpha1",
+			Served:  true,
+			Storage: false,
+		},
+		{
+			Name:    "v1alpha2",
+			Served:  true,
+			Storage: true,
+		},
+	}
+
+	missingVersions := []v1beta1.CustomResourceDefinitionVersion{
+		{
+			Name:    "v1alpha2",
+			Served:  true,
+			Storage: true,
+		},
+	}
+
+	tests := []struct {
+		name            string
+		oldCRD          v1beta1.CustomResourceDefinition
+		newCRD          v1beta1.CustomResourceDefinition
+		expectedFailure bool
+	}{
+		{
+			name: "existing versions are present",
+			oldCRD: func() v1beta1.CustomResourceDefinition {
+				oldCRD := crd(mainCRDPlural)
+				oldCRD.Spec.Version = ""
+				oldCRD.Spec.Versions = currentVersions
+				return oldCRD
+			}(),
+			newCRD: func() v1beta1.CustomResourceDefinition {
+				newCRD := crd(mainCRDPlural)
+				newCRD.Spec.Version = ""
+				newCRD.Spec.Versions = addedVersions
+				return newCRD
+			}(),
+			expectedFailure: false,
+		},
+		{
+			name: "missing versions in new CRD",
+			oldCRD: func() v1beta1.CustomResourceDefinition {
+				oldCRD := crd(mainCRDPlural)
+				oldCRD.Spec.Version = ""
+				oldCRD.Spec.Versions = currentVersions
+				return oldCRD
+			}(),
+			newCRD: func() v1beta1.CustomResourceDefinition {
+				newCRD := crd(mainCRDPlural)
+				newCRD.Spec.Version = ""
+				newCRD.Spec.Versions = missingVersions
+				return newCRD
+			}(),
+			expectedFailure: true,
+		},
+		{
+			name: "missing version in new CRD",
+			oldCRD: func() v1beta1.CustomResourceDefinition {
+				oldCRD := crd(mainCRDPlural)
+				oldCRD.Spec.Version = "v1alpha1"
+				return oldCRD
+			}(),
+			newCRD: func() v1beta1.CustomResourceDefinition {
+				newCRD := crd(mainCRDPlural)
+				newCRD.Spec.Version = "v1alpha2"
+				return newCRD
+			}(),
+			expectedFailure: true,
+		},
+		{
+			name: "existing version is present in new CRD's versions",
+			oldCRD: func() v1beta1.CustomResourceDefinition {
+				oldCRD := crd(mainCRDPlural)
+				oldCRD.Spec.Version = "v1alpha1"
+				return oldCRD
+			}(),
+			newCRD: func() v1beta1.CustomResourceDefinition {
+				newCRD := crd(mainCRDPlural)
+				newCRD.Spec.Version = ""
+				newCRD.Spec.Versions = addedVersions
+				return newCRD
+			}(),
+			expectedFailure: false,
+		},
+	}
+
+	for _, tt := range tests {
+		err := ensureCRDVersions(&tt.oldCRD, &tt.newCRD)
+		if tt.expectedFailure {
+			require.Error(t, err)
+		}
+	}
+}
+
+func TestRemoveDeprecatedStoredVersions(t *testing.T) {
+	mainCRDPlural := "ins-main-test"
+
+	currentVersions := []v1beta1.CustomResourceDefinitionVersion{
+		{
+			Name:    "v1alpha1",
+			Served:  true,
+			Storage: false,
+		},
+		{
+			Name:    "v1alpha2",
+			Served:  true,
+			Storage: true,
+		},
+	}
+
+	newVersions := []v1beta1.CustomResourceDefinitionVersion{
+		{
+			Name:    "v1alpha2",
+			Served:  true,
+			Storage: false,
+		},
+		{
+			Name:    "v1beta1",
+			Served:  true,
+			Storage: true,
+		},
+	}
+
+	crdStatusStoredVersions := v1beta1.CustomResourceDefinitionStatus{
+		StoredVersions: []string{},
+	}
+
+	tests := []struct {
+		name           string
+		oldCRD         v1beta1.CustomResourceDefinition
+		newCRD         v1beta1.CustomResourceDefinition
+		expectedResult []string
+	}{
+		{
+			name: "only one stored version exists",
+			oldCRD: func() v1beta1.CustomResourceDefinition {
+				oldCRD := crd(mainCRDPlural)
+				oldCRD.Spec.Version = ""
+				oldCRD.Spec.Versions = currentVersions
+				oldCRD.Status = crdStatusStoredVersions
+				oldCRD.Status.StoredVersions = []string{"v1alpha1"}
+				return oldCRD
+			}(),
+			newCRD: func() v1beta1.CustomResourceDefinition {
+				newCRD := crd(mainCRDPlural)
+				newCRD.Spec.Version = ""
+				newCRD.Spec.Versions = newVersions
+				return newCRD
+			}(),
+			expectedResult: nil,
+		},
+		{
+			name: "multiple stored versions with one deprecated version",
+			oldCRD: func() v1beta1.CustomResourceDefinition {
+				oldCRD := crd(mainCRDPlural)
+				oldCRD.Spec.Version = ""
+				oldCRD.Spec.Versions = currentVersions
+				oldCRD.Status.StoredVersions = []string{"v1alpha1", "v1alpha2"}
+				return oldCRD
+			}(),
+			newCRD: func() v1beta1.CustomResourceDefinition {
+				newCRD := crd(mainCRDPlural)
+				newCRD.Spec.Version = ""
+				newCRD.Spec.Versions = newVersions
+				return newCRD
+			}(),
+			expectedResult: []string{"v1alpha2"},
+		},
+		{
+			name: "multiple stored versions with all deprecated version",
+			oldCRD: func() v1beta1.CustomResourceDefinition {
+				oldCRD := crd(mainCRDPlural)
+				oldCRD.Spec.Version = ""
+				oldCRD.Spec.Versions = currentVersions
+				oldCRD.Status.StoredVersions = []string{"v1alpha1", "v1alpha3"}
+				return oldCRD
+			}(),
+			newCRD: func() v1beta1.CustomResourceDefinition {
+				newCRD := crd(mainCRDPlural)
+				newCRD.Spec.Version = ""
+				newCRD.Spec.Versions = newVersions
+				return newCRD
+			}(),
+			expectedResult: nil,
+		},
+	}
+
+	for _, tt := range tests {
+		resultCRD := removeDeprecatedStoredVersions(&tt.oldCRD, &tt.newCRD)
+		require.Equal(t, tt.expectedResult, resultCRD)
+	}
+}
+
 func TestExecutePlan(t *testing.T) {
 	namespace := "ns"
 
@@ -143,11 +357,11 @@ func TestExecutePlan(t *testing.T) {
 						Resource: v1alpha1.StepResource{
 							CatalogSource:          "catalog",
 							CatalogSourceNamespace: namespace,
-							Group:    "",
-							Version:  "v1",
-							Kind:     "Service",
-							Name:     "service",
-							Manifest: toManifest(service("service", namespace)),
+							Group:                  "",
+							Version:                "v1",
+							Kind:                   "Service",
+							Name:                   "service",
+							Manifest:               toManifest(service("service", namespace)),
 						},
 						Status: v1alpha1.StepStatusUnknown,
 					},
@@ -155,11 +369,11 @@ func TestExecutePlan(t *testing.T) {
 						Resource: v1alpha1.StepResource{
 							CatalogSource:          "catalog",
 							CatalogSourceNamespace: namespace,
-							Group:    "operators.coreos.com",
-							Version:  "v1alpha1",
-							Kind:     "ClusterServiceVersion",
-							Name:     "csv",
-							Manifest: toManifest(csv("csv", namespace, nil, nil)),
+							Group:                  "operators.coreos.com",
+							Version:                "v1alpha1",
+							Kind:                   "ClusterServiceVersion",
+							Name:                   "csv",
+							Manifest:               toManifest(csv("csv", namespace, nil, nil)),
 						},
 						Status: v1alpha1.StepStatusUnknown,
 					},
@@ -168,13 +382,104 @@ func TestExecutePlan(t *testing.T) {
 			want: []runtime.Object{service("service", namespace), csv("csv", namespace, nil, nil)},
 			err:  nil,
 		},
+		{
+			testName: "CreateServiceAccount",
+			in: withSteps(installPlan("p", namespace, v1alpha1.InstallPlanPhaseInstalling, "csv"),
+				[]*v1alpha1.Step{
+					{
+						Resource: v1alpha1.StepResource{
+							CatalogSource:          "catalog",
+							CatalogSourceNamespace: namespace,
+							Group:                  "",
+							Version:                "v1",
+							Kind:                   "ServiceAccount",
+							Name:                   "sa",
+							Manifest: toManifest(serviceAccount("sa", namespace, "",
+								objectReference("init secret"))),
+						},
+						Status: v1alpha1.StepStatusUnknown,
+					},
+				},
+			),
+			want: []runtime.Object{serviceAccount("sa", namespace, "", objectReference("init secret"))},
+			err:  nil,
+		},
+		{
+			testName: "UpdateServiceAccountWithSameFields",
+			in: withSteps(installPlan("p", namespace, v1alpha1.InstallPlanPhaseInstalling, "csv"),
+				[]*v1alpha1.Step{
+					{
+						Resource: v1alpha1.StepResource{
+							CatalogSource:          "catalog",
+							CatalogSourceNamespace: namespace,
+							Group:                  "",
+							Version:                "v1",
+							Kind:                   "ServiceAccount",
+							Name:                   "sa",
+							Manifest: toManifest(serviceAccount("sa", namespace, "name",
+								objectReference("init secret"))),
+						},
+						Status: v1alpha1.StepStatusUnknown,
+					},
+					{
+						Resource: v1alpha1.StepResource{
+							CatalogSource:          "catalog",
+							CatalogSourceNamespace: namespace,
+							Group:                  "",
+							Version:                "v1",
+							Kind:                   "ServiceAccount",
+							Name:                   "sa",
+							Manifest:               toManifest(serviceAccount("sa", namespace, "name", nil)),
+						},
+						Status: v1alpha1.StepStatusUnknown,
+					},
+				},
+			),
+			want: []runtime.Object{serviceAccount("sa", namespace, "name", objectReference("init secret"))},
+			err:  nil,
+		},
+		{
+			testName: "UpdateServiceAccountWithDiffFields",
+			in: withSteps(installPlan("p", namespace, v1alpha1.InstallPlanPhaseInstalling, "csv"),
+				[]*v1alpha1.Step{
+					{
+						Resource: v1alpha1.StepResource{
+							CatalogSource:          "catalog",
+							CatalogSourceNamespace: namespace,
+							Group:                  "",
+							Version:                "v1",
+							Kind:                   "ServiceAccount",
+							Name:                   "sa",
+							Manifest: toManifest(serviceAccount("sa", namespace, "old_name",
+								objectReference("init secret"))),
+						},
+						Status: v1alpha1.StepStatusUnknown,
+					},
+					{
+						Resource: v1alpha1.StepResource{
+							CatalogSource:          "catalog",
+							CatalogSourceNamespace: namespace,
+							Group:                  "",
+							Version:                "v1",
+							Kind:                   "ServiceAccount",
+							Name:                   "sa",
+							Manifest:               toManifest(serviceAccount("sa", namespace, "new_name", nil)),
+						},
+						Status: v1alpha1.StepStatusUnknown,
+					},
+				},
+			),
+			want: []runtime.Object{serviceAccount("sa", namespace, "new_name", objectReference("init secret"))},
+			err:  nil,
+		},
 	}
 
 	for _, tt := range tests {
 		t.Run(tt.testName, func(t *testing.T) {
-			ctx, cancel := context.WithCancel(context.Background())
+			ctx, cancel := context.WithCancel(context.TODO())
 			defer cancel()
-			op, err := NewFakeOperator(namespace, []string{namespace}, ctx, withClientObjs(tt.in))
+
+			op, err := NewFakeOperator(ctx, namespace, []string{namespace}, withClientObjs(tt.in))
 			require.NoError(t, err)
 
 			err = op.ExecutePlan(tt.in)
@@ -185,19 +490,21 @@ func TestExecutePlan(t *testing.T) {
 				var fetched runtime.Object
 				switch o := obj.(type) {
 				case *appsv1.Deployment:
-					fetched, err = op.OpClient.GetDeployment(namespace, o.GetName())
+					fetched, err = op.opClient.GetDeployment(namespace, o.GetName())
 				case *rbacv1.ClusterRole:
-					fetched, err = op.OpClient.GetClusterRole(o.GetName())
+					fetched, err = op.opClient.GetClusterRole(o.GetName())
 				case *rbacv1.Role:
-					fetched, err = op.OpClient.GetRole(namespace, o.GetName())
+					fetched, err = op.opClient.GetRole(namespace, o.GetName())
 				case *rbacv1.ClusterRoleBinding:
-					fetched, err = op.OpClient.GetClusterRoleBinding(o.GetName())
+					fetched, err = op.opClient.GetClusterRoleBinding(o.GetName())
 				case *rbacv1.RoleBinding:
-					fetched, err = op.OpClient.GetRoleBinding(namespace, o.GetName())
+					fetched, err = op.opClient.GetRoleBinding(namespace, o.GetName())
 				case *corev1.ServiceAccount:
-					fetched, err = op.OpClient.GetServiceAccount(namespace, o.GetName())
+					fetched, err = op.opClient.GetServiceAccount(namespace, o.GetName())
+				case *corev1.Secret:
+					fetched, err = op.opClient.GetSecret(namespace, o.GetName())
 				case *corev1.Service:
-					fetched, err = op.OpClient.GetService(namespace, o.GetName())
+					fetched, err = op.opClient.GetService(namespace, o.GetName())
 				case *v1alpha1.ClusterServiceVersion:
 					fetched, err = op.client.OperatorsV1alpha1().ClusterServiceVersions(namespace).Get(o.GetName(), metav1.GetOptions{})
 				default:
@@ -212,8 +519,8 @@ func TestExecutePlan(t *testing.T) {
 }
 
 func TestSyncCatalogSources(t *testing.T) {
-	nowTime := metav1.Date(2018, time.January, 26, 20, 40, 0, 0, time.UTC)
-	timeNow = func() metav1.Time { return nowTime }
+	clockFake := utilclock.NewFakeClock(time.Date(2018, time.January, 26, 20, 40, 0, 0, time.UTC))
+	now := metav1.NewTime(clockFake.Now())
 
 	configmapCatalog := &v1alpha1.CatalogSource{
 		ObjectMeta: metav1.ObjectMeta{
@@ -231,6 +538,7 @@ func TestSyncCatalogSources(t *testing.T) {
 			Name:      "cool-catalog",
 			Namespace: "cool-namespace",
 			UID:       types.UID("catalog-uid"),
+			Labels:    map[string]string{"olm.catalogSource": "cool-catalog"},
 		},
 		Spec: v1alpha1.CatalogSourceSpec{
 			Image:      "catalog-image",
@@ -296,9 +604,9 @@ func TestSyncCatalogSources(t *testing.T) {
 					Namespace:       "cool-namespace",
 					UID:             types.UID("configmap-uid"),
 					ResourceVersion: "resource-version",
+					LastUpdateTime: now,
 				},
 				RegistryServiceStatus: nil,
-				LastSync:              timeNow(),
 			},
 			expectedError: nil,
 		},
@@ -321,9 +629,9 @@ func TestSyncCatalogSources(t *testing.T) {
 						Namespace:       "cool-namespace",
 						UID:             types.UID("configmap-uid"),
 						ResourceVersion: "resource-version",
+						LastUpdateTime:  now,
 					},
 					RegistryServiceStatus: nil,
-					LastSync:              timeNow(),
 				},
 			},
 			k8sObjs: []runtime.Object{
@@ -343,15 +651,15 @@ func TestSyncCatalogSources(t *testing.T) {
 					Namespace:       "cool-namespace",
 					UID:             types.UID("configmap-uid"),
 					ResourceVersion: "resource-version",
+					LastUpdateTime:  now,
 				},
 				RegistryServiceStatus: &v1alpha1.RegistryServiceStatus{
 					Protocol:         "grpc",
 					ServiceName:      "cool-catalog",
 					ServiceNamespace: "cool-namespace",
 					Port:             "50051",
-					CreatedAt:        timeNow(),
+					CreatedAt:        now,
 				},
-				LastSync: timeNow(),
 			},
 			expectedError: nil,
 		},
@@ -375,9 +683,8 @@ func TestSyncCatalogSources(t *testing.T) {
 					ServiceName:      "cool-catalog",
 					ServiceNamespace: "cool-namespace",
 					Port:             "50051",
-					CreatedAt:        timeNow(),
+					CreatedAt:        now,
 				},
-				LastSync: timeNow(),
 			},
 			expectedError: nil,
 			expectedObjs: []runtime.Object{
@@ -394,6 +701,7 @@ func TestSyncCatalogSources(t *testing.T) {
 						Name:      "cool-catalog",
 						Namespace: "cool-namespace",
 						UID:       types.UID("catalog-uid"),
+						Labels:    map[string]string{"olm.catalogSource": "cool-catalog"},
 					},
 					Spec: v1alpha1.CatalogSourceSpec{
 						Image:      "old-image",
@@ -407,9 +715,8 @@ func TestSyncCatalogSources(t *testing.T) {
 					ServiceName:      "cool-catalog",
 					ServiceNamespace: "cool-namespace",
 					Port:             "50051",
-					CreatedAt:        timeNow(),
+					CreatedAt:        now,
 				},
-				LastSync: timeNow(),
 			},
 			expectedError: nil,
 			expectedObjs: []runtime.Object{
@@ -423,10 +730,10 @@ func TestSyncCatalogSources(t *testing.T) {
 			clientObjs := []runtime.Object{tt.catalogSource}
 
 			// Create test operator
-			ctx, cancel := context.WithCancel(context.Background())
+			ctx, cancel := context.WithCancel(context.TODO())
 			defer cancel()
 
-			op, err := NewFakeOperator(tt.namespace, []string{tt.namespace}, ctx, withClientObjs(clientObjs...), withK8sObjs(tt.k8sObjs...))
+			op, err := NewFakeOperator(ctx, tt.namespace, []string{tt.namespace}, withClock(clockFake), withClientObjs(clientObjs...), withK8sObjs(tt.k8sObjs...))
 			require.NoError(t, err)
 
 			// Run sync
@@ -444,17 +751,10 @@ func TestSyncCatalogSources(t *testing.T) {
 
 			if tt.expectedStatus != nil {
 				require.NotEmpty(t, updated.Status)
-				require.Equal(t, tt.expectedStatus.LastSync, updated.Status.LastSync)
-
-				if tt.expectedStatus.RegistryServiceStatus != nil {
-					require.True(t, tt.expectedStatus.RegistryServiceStatus.CreatedAt.Time.Sub(updated.Status.RegistryServiceStatus.CreatedAt.Time) < 2*time.Second)
-					tt.expectedStatus.RegistryServiceStatus.CreatedAt = updated.Status.RegistryServiceStatus.CreatedAt
-				}
-
 				require.Equal(t, *tt.expectedStatus, updated.Status)
 
 				if tt.catalogSource.Spec.ConfigMap != "" {
-					configMap, err := op.OpClient.KubernetesInterface().CoreV1().ConfigMaps(tt.catalogSource.GetNamespace()).Get(tt.catalogSource.Spec.ConfigMap, metav1.GetOptions{})
+					configMap, err := op.opClient.KubernetesInterface().CoreV1().ConfigMaps(tt.catalogSource.GetNamespace()).Get(tt.catalogSource.Spec.ConfigMap, metav1.GetOptions{})
 					require.NoError(t, err)
 					require.True(t, ownerutil.EnsureOwner(configMap, updated))
 				}
@@ -464,7 +764,7 @@ func TestSyncCatalogSources(t *testing.T) {
 				switch o.(type) {
 				case *corev1.Pod:
 					t.Log("verifying pod")
-					pods, err := op.OpClient.KubernetesInterface().CoreV1().Pods(tt.catalogSource.Namespace).List(metav1.ListOptions{})
+					pods, err := op.opClient.KubernetesInterface().CoreV1().Pods(tt.catalogSource.Namespace).List(metav1.ListOptions{})
 					require.NoError(t, err)
 					require.Len(t, pods.Items, 1)
 
@@ -563,16 +863,38 @@ func fakeConfigMapData() map[string]string {
 
 // fakeOperatorConfig is the configuration for a fake operator.
 type fakeOperatorConfig struct {
+	clock         utilclock.Clock
 	clientObjs    []runtime.Object
 	k8sObjs       []runtime.Object
 	extObjs       []runtime.Object
 	regObjs       []runtime.Object
 	clientOptions []clientfake.Option
+	logger        *logrus.Logger
+	resolver      resolver.Resolver
+	reconciler    reconciler.RegistryReconcilerFactory
 }
 
 // fakeOperatorOption applies an option to the given fake operator configuration.
 type fakeOperatorOption func(*fakeOperatorConfig)
 
+func withResolver(res resolver.Resolver) fakeOperatorOption {
+	return func(config *fakeOperatorConfig) {
+		config.resolver = res
+	}
+}
+
+func withReconciler(rec reconciler.RegistryReconcilerFactory) fakeOperatorOption {
+	return func(config *fakeOperatorConfig) {
+		config.reconciler = rec
+	}
+}
+
+func withClock(clock utilclock.Clock) fakeOperatorOption {
+	return func(config *fakeOperatorConfig) {
+		config.clock = clock
+	}
+}
+
 func withClientObjs(clientObjs ...runtime.Object) fakeOperatorOption {
 	return func(config *fakeOperatorConfig) {
 		config.clientObjs = clientObjs
@@ -598,9 +920,13 @@ func withFakeClientOptions(options ...clientfake.Option) fakeOperatorOption {
 }
 
 // NewFakeOperator creates a new operator using fake clients.
-func NewFakeOperator(namespace string, watchedNamespaces []string, ctx context.Context, fakeOptions ...fakeOperatorOption) (*Operator, error) {
+func NewFakeOperator(ctx context.Context, namespace string, watchedNamespaces []string, fakeOptions ...fakeOperatorOption) (*Operator, error) {
 	// Apply options to default config
-	config := &fakeOperatorConfig{}
+	config := &fakeOperatorConfig{
+		logger:   logrus.StandardLogger(),
+		clock:    utilclock.RealClock{},
+		resolver: &fakes.FakeResolver{},
+	}
 	for _, option := range fakeOptions {
 		option(config)
 	}
@@ -657,33 +983,43 @@ func NewFakeOperator(namespace string, watchedNamespaces []string, ctx context.C
 
 	}
 
+	logger := logrus.New()
+
 	// Create the new operator
-	queueOperator, err := queueinformer.NewOperatorFromClient(opClientFake, logrus.New())
+	queueOperator, err := queueinformer.NewOperator(opClientFake.KubernetesInterface().Discovery())
+	for _, informer := range sharedInformers {
+		queueOperator.RegisterInformer(informer)
+	}
+
 	op := &Operator{
 		Operator:  queueOperator,
+		clock:     config.clock,
+		logger:    config.logger,
+		opClient:  opClientFake,
 		client:    clientFake,
 		lister:    lister,
 		namespace: namespace,
-		namespaceResolveQueue: workqueue.NewNamedRateLimitingQueue(
+		nsResolveQueue: workqueue.NewNamedRateLimitingQueue(
 			workqueue.NewMaxOfRateLimiter(
 				workqueue.NewItemExponentialFailureRateLimiter(1*time.Second, 1000*time.Second),
 				// 1 qps, 100 bucket size.  This is only for retry speed and its only the overall factor (not per item)
 				&workqueue.BucketRateLimiter{Limiter: rate.NewLimiter(rate.Limit(1), 100)},
 			), "resolver"),
-		resolver: &fakes.FakeResolver{},
+		resolver:              config.resolver,
+		reconciler:            config.reconciler,
+		clientAttenuator:      scoped.NewClientAttenuator(logger, &rest.Config{}, opClientFake, clientFake),
+		serviceAccountQuerier: scoped.NewUserDefinedServiceAccountQuerier(logger, clientFake),
+		catsrcQueueSet:         queueinformer.NewEmptyResourceQueueSet(),
+	}
+	op.sources = grpc.NewSourceStore(config.logger, 1*time.Second, 5*time.Second, op.syncSourceState)
+	if op.reconciler == nil {
+		op.reconciler = reconciler.NewRegistryReconcilerFactory(lister, op.opClient, "test:pod", op.now)
 	}
-	op.sources = grpc.NewSourceStore(logrus.StandardLogger(), 1*time.Second, 5*time.Second, op.syncSourceState)
-	op.reconciler = reconciler.NewRegistryReconcilerFactory(lister, op.OpClient, "test:pod")
 
-	var hasSyncedCheckFns []cache.InformerSynced
-	for _, informer := range sharedInformers {
-		op.RegisterInformer(informer)
-		hasSyncedCheckFns = append(hasSyncedCheckFns, informer.HasSynced)
-		go informer.Run(ctx.Done())
-	}
+	op.RunInformers(ctx)
 	op.sources.Start(ctx)
 
-	if ok := cache.WaitForCacheSync(ctx.Done(), hasSyncedCheckFns...); !ok {
+	if ok := cache.WaitForCacheSync(ctx.Done(), op.HasSynced); !ok {
 		return nil, fmt.Errorf("failed to wait for caches to sync")
 	}
 
@@ -766,56 +1102,32 @@ func service(name, namespace string) *corev1.Service {
 	}
 }
 
+func serviceAccount(name, namespace, generateName string, secretRef *corev1.ObjectReference) *corev1.ServiceAccount {
+	if secretRef == nil {
+		return &corev1.ServiceAccount{
+			ObjectMeta: metav1.ObjectMeta{Name: name, Namespace: namespace, GenerateName: generateName},
+		}
+	}
+	return &corev1.ServiceAccount{
+		ObjectMeta: metav1.ObjectMeta{Name: name, Namespace: namespace, GenerateName: generateName},
+		Secrets:    []corev1.ObjectReference{*secretRef},
+	}
+}
+
+func objectReference(name string) *corev1.ObjectReference {
+	if name == "" {
+		return &corev1.ObjectReference{}
+	}
+	return &corev1.ObjectReference{Name: name}
+}
+
 func toManifest(obj runtime.Object) string {
 	raw, _ := json.Marshal(obj)
 	return string(raw)
 }
 
 func pod(s v1alpha1.CatalogSource) *corev1.Pod {
-	pod := &corev1.Pod{
-		ObjectMeta: metav1.ObjectMeta{
-			GenerateName: s.GetName() + "-",
-			Namespace:    s.GetNamespace(),
-			Labels: map[string]string{
-				"olm.catalogSource": s.GetName(),
-			},
-		},
-		Spec: corev1.PodSpec{
-			Containers: []corev1.Container{
-				{
-					Name:  "registry-server",
-					Image: s.Spec.Image,
-					Ports: []corev1.ContainerPort{
-						{
-							Name:          "grpc",
-							ContainerPort: 50051,
-						},
-					},
-					ReadinessProbe: &corev1.Probe{
-						Handler: corev1.Handler{
-							Exec: &corev1.ExecAction{
-								Command: []string{"grpc_health_probe", "-addr=localhost:50051"},
-							},
-						},
-						InitialDelaySeconds: 5,
-					},
-					LivenessProbe: &corev1.Probe{
-						Handler: corev1.Handler{
-							Exec: &corev1.ExecAction{
-								Command: []string{"grpc_health_probe", "-addr=localhost:50051"},
-							},
-						},
-						InitialDelaySeconds: 10,
-					},
-				},
-			},
-			Tolerations: []corev1.Toleration{
-				{
-					Operator: corev1.TolerationOpExists,
-				},
-			},
-		},
-	}
+	pod := reconciler.Pod(&s, "registry-server", s.Spec.Image, s.GetLabels(), 5, 10)
 	ownerutil.AddOwner(pod, &s, false, false)
 	return pod
 }
