@@ -5,6 +5,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/labels"
 
+	olmv1alpha1 "github.com/operator-framework/operator-lifecycle-manager/pkg/api/apis/operators/v1alpha1"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/api/client/clientset/versioned"
 	v1alpha1 "github.com/operator-framework/operator-lifecycle-manager/pkg/api/client/listers/operators/v1alpha1"
 )
@@ -12,7 +13,11 @@ import (
 const (
 	NAME_LABEL      = "name"
 	INSTALLED_LABEL = "installed"
-	PACKAGE_LABEL   = "package"
+	NAMESPACE_LABEL = "namespace"
+	CHANNEL_LABEL   = "channel"
+	VERSION_LABEL   = "version"
+	PHASE_LABEL     = "phase"
+	REASON_LABEL    = "reason"
 )
 
 // TODO(alecmerdler): Can we use this to emit Kubernetes events?
@@ -144,12 +149,30 @@ var (
 			Name: "subscription_sync_total",
 			Help: "Monotonic count of subscription syncs",
 		},
-		[]string{NAME_LABEL, INSTALLED_LABEL, PACKAGE_LABEL},
+		[]string{NAME_LABEL, INSTALLED_LABEL, CHANNEL_LABEL},
+	)
+
+	csvSucceeded = prometheus.NewGaugeVec(
+		prometheus.GaugeOpts{
+			Name: "csv_succeeded",
+			Help: "Successful CSV install",
+		},
+		[]string{NAMESPACE_LABEL, NAME_LABEL, VERSION_LABEL},
+	)
+
+	csvAbnormal = prometheus.NewGaugeVec(
+		prometheus.GaugeOpts{
+			Name: "csv_abnormal",
+			Help: "CSV is not installed",
+		},
+		[]string{NAMESPACE_LABEL, NAME_LABEL, VERSION_LABEL, PHASE_LABEL, REASON_LABEL},
 	)
 )
 
 func RegisterOLM() {
 	prometheus.MustRegister(csvCount)
+	prometheus.MustRegister(csvSucceeded)
+	prometheus.MustRegister(csvAbnormal)
 	prometheus.MustRegister(CSVUpgradeCount)
 }
 
@@ -160,6 +183,30 @@ func RegisterCatalog() {
 	prometheus.MustRegister(SubscriptionSyncCount)
 }
 
-func CounterForSubscription(name, installedCSV, packageName string) prometheus.Counter {
-	return SubscriptionSyncCount.WithLabelValues(name, installedCSV, packageName)
+func CounterForSubscription(name, installedCSV, channelName string) prometheus.Counter {
+	return SubscriptionSyncCount.WithLabelValues(name, installedCSV, channelName)
+}
+
+func EmitCSVMetric(oldCSV *olmv1alpha1.ClusterServiceVersion, newCSV *olmv1alpha1.ClusterServiceVersion) {
+	if oldCSV == nil || newCSV == nil {
+		return
+	}
+
+	// Don't update the metric for copies
+	if newCSV.Status.Reason == olmv1alpha1.CSVReasonCopied {
+		return
+	}
+
+	// Delete the old CSV metrics
+	csvAbnormal.DeleteLabelValues(oldCSV.Namespace, oldCSV.Name, oldCSV.Spec.Version.String(), string(oldCSV.Status.Phase), string(oldCSV.Status.Reason))
+
+	// Get the phase of the new CSV
+	newCSVPhase := string(newCSV.Status.Phase)
+	csvSucceededGauge := csvSucceeded.WithLabelValues(newCSV.Namespace, newCSV.Name, newCSV.Spec.Version.String())
+	if newCSVPhase == string(olmv1alpha1.CSVPhaseSucceeded) {
+		csvSucceededGauge.Set(1)
+	} else {
+		csvSucceededGauge.Set(0)
+		csvAbnormal.WithLabelValues(newCSV.Namespace, newCSV.Name, newCSV.Spec.Version.String(), string(newCSV.Status.Phase), string(newCSV.Status.Reason)).Set(1)
+	}
 }
